#[non_exhaustive]pub struct CreateDataAutomationLibraryOutput {
pub library_arn: Option<String>,
pub status: Option<DataAutomationLibraryStatus>,
/* private fields */
}Expand description
Create DataAutomationLibrary Response
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.library_arn: Option<String>ARN generated at the server side when a DataAutomationLibrary is created
status: Option<DataAutomationLibraryStatus>Status of DataAutomationLibrary
Implementations
Sourceimpl CreateDataAutomationLibraryOutput
impl CreateDataAutomationLibraryOutput
Sourcepub fn library_arn(&self) -> Option<&str>
pub fn library_arn(&self) -> Option<&str>
ARN generated at the server side when a DataAutomationLibrary is created
Sourcepub fn status(&self) -> Option<&DataAutomationLibraryStatus>
pub fn status(&self) -> Option<&DataAutomationLibraryStatus>
Status of DataAutomationLibrary
Sourceimpl CreateDataAutomationLibraryOutput
impl CreateDataAutomationLibraryOutput
Sourcepub fn builder() -> CreateDataAutomationLibraryOutputBuilder
pub fn builder() -> CreateDataAutomationLibraryOutputBuilder
Creates a new builder-style object to manufacture CreateDataAutomationLibraryOutput.