#[non_exhaustive]pub struct DataAutomationLibrary {
pub library_arn: String,
pub creation_time: DateTime,
pub library_name: String,
pub library_description: Option<String>,
pub status: DataAutomationLibraryStatus,
pub entity_types: Option<Vec<EntityTypeInfo>>,
pub kms_key_id: Option<String>,
pub kms_encryption_context: Option<HashMap<String, String>>,
}Expand description
Contains the information of a DataAutomationLibrary.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.library_arn: StringARN generated at the server side when a DataAutomationLibrary is created
creation_time: DateTimeTime Stamp
library_name: StringName of the DataAutomationLibrary
library_description: Option<String>Description of the DataAutomationLibrary
status: DataAutomationLibraryStatusStatus of DataAutomationLibrary
entity_types: Option<Vec<EntityTypeInfo>>List of info for each entity type in the DataAutomationLibrary
kms_key_id: Option<String>KMS Key Identifier
kms_encryption_context: Option<HashMap<String, String>>KMS Encryption Context
Implementations
Sourceimpl DataAutomationLibrary
impl DataAutomationLibrary
Sourcepub fn library_arn(&self) -> &str
pub fn library_arn(&self) -> &str
ARN generated at the server side when a DataAutomationLibrary is created
Sourcepub fn creation_time(&self) -> &DateTime
pub fn creation_time(&self) -> &DateTime
Time Stamp
Sourcepub fn library_name(&self) -> &str
pub fn library_name(&self) -> &str
Name of the DataAutomationLibrary
Sourcepub fn library_description(&self) -> Option<&str>
pub fn library_description(&self) -> Option<&str>
Description of the DataAutomationLibrary
Sourcepub fn status(&self) -> &DataAutomationLibraryStatus
pub fn status(&self) -> &DataAutomationLibraryStatus
Status of DataAutomationLibrary
Sourcepub fn entity_types(&self) -> &[EntityTypeInfo]
pub fn entity_types(&self) -> &[EntityTypeInfo]
List of info for each entity type in the DataAutomationLibrary
If no value was sent for this field, a default will be set. If you want to determine if no value was sent, use .entity_types.is_none().
Sourcepub fn kms_key_id(&self) -> Option<&str>
pub fn kms_key_id(&self) -> Option<&str>
KMS Key Identifier
Sourceimpl DataAutomationLibrary
impl DataAutomationLibrary
Sourcepub fn builder() -> DataAutomationLibraryBuilder
pub fn builder() -> DataAutomationLibraryBuilder
Creates a new builder-style object to manufacture DataAutomationLibrary.